@@ -63,6 +63,6 @@ def ecg_quality(ecg_cleaned, rpeaks=None, sampling_rate=1000):
     quality[nonmissing] = dist
 
     # Interpolate
-    quality = signal_interpolate(rpeaks, quality, desired_length=len(ecg_cleaned), method="quadratic")
+    quality = signal_interpolate(rpeaks, quality, x_new=np.arange(len(ecg_cleaned)), method="quadratic")
 
     return quality
