@@ -1,8 +1,8 @@
 """Submodule for NeuroKit."""
 
 from .events_find import events_find
+from .events_create import events_create
 from .events_plot import events_plot
 from .events_to_mne import events_to_mne
 
-
-__all__ = ["events_find", "events_plot", "events_to_mne"]
+__all__ = ["events_find", "events_create", "events_plot", "events_to_mne"]
