@@ -9,11 +9,11 @@ def signal_formatpeaks(info, desired_length, peak_indices=None):
         peak_indices = [key for key in info.keys() if "Peaks" in key]
 
     signals = {}
-    for feature in info.keys():
+    for feature, values in info.items():
         if any(x in str(feature) for x in ["Peak", "Onset", "Offset", "Trough", "Recovery"]):
-            signals[feature] = _signal_from_indices(info[feature], desired_length, 1)
+            signals[feature] = _signal_from_indices(values, desired_length, 1)
         else:
-            signals[feature] = _signal_from_indices(peak_indices, desired_length, info[feature])
+            signals[feature] = _signal_from_indices(peak_indices, desired_length, values)
     signals = pd.DataFrame(signals)
     return signals
 
@@ -29,11 +29,16 @@ def _signal_from_indices(indices, desired_length=None, value=1):
     Used in *_findpeaks to transform vectors of peak indices to signal.
 
     """
-    signal = np.zeros(desired_length)
+    signal = np.zeros(desired_length, dtype=int)
+
+    if isinstance(indices, list) and (not indices):    # skip empty lists
+        return signal
+    if isinstance(indices, np.ndarray) and (indices.size == 0):    # skip empty arrays
+        return signal
 
     # Force indices as int
-    if isinstance(indices[0], np.float):
-        indices = indices[~np.isnan(indices)].astype(np.int)
+    if isinstance(indices[0], float):
+        indices = indices[~np.isnan(indices)].astype(int)
 
     if isinstance(value, (int, float)):
         signal[indices] = value
@@ -47,7 +52,7 @@ def _signal_from_indices(indices, desired_length=None, value=1):
     return signal
 
 
-def _signal_formatpeaks_sanitize(peaks, key="Peaks"):
+def _signal_formatpeaks_sanitize(peaks, key="Peaks"):    # FIXME: private function not used in this module
     # Attempt to retrieve column.
     if isinstance(peaks, tuple):
         if isinstance(peaks[0], (dict, pd.DataFrame)):
