@@ -31,7 +31,12 @@ def test_eda_clean():
 
     sampling_rate = 1000
     eda = nk.eda_simulate(
-        duration=30, sampling_rate=sampling_rate, scr_number=6, noise=0.01, drift=0.01, random_state=42
+        duration=30,
+        sampling_rate=sampling_rate,
+        scr_number=6,
+        noise=0.01,
+        drift=0.01,
+        random_state=42,
     )
 
     clean = nk.eda_clean(eda, sampling_rate=sampling_rate)
@@ -41,10 +46,17 @@ def test_eda_clean():
 
     eda_biosppy = nk.eda_clean(eda, sampling_rate=sampling_rate, method="biosppy")
     original, _, _ = biosppy.tools.filter_signal(
-        signal=eda, ftype="butter", band="lowpass", order=4, frequency=5, sampling_rate=sampling_rate
+        signal=eda,
+        ftype="butter",
+        band="lowpass",
+        order=4,
+        frequency=5,
+        sampling_rate=sampling_rate,
     )
 
-    original, _ = biosppy.tools.smoother(signal=original, kernel="boxzen", size=int(0.75 * sampling_rate), mirror=True)
+    original, _ = biosppy.tools.smoother(
+        signal=original, kernel="boxzen", size=int(0.75 * sampling_rate), mirror=True
+    )
 
     #    pd.DataFrame({"our":eda_biosppy, "biosppy":original}).plot()
     assert np.allclose((eda_biosppy - original).mean(), 0, atol=1e-5)
@@ -54,7 +66,12 @@ def test_eda_phasic():
 
     sampling_rate = 1000
     eda = nk.eda_simulate(
-        duration=30, sampling_rate=sampling_rate, scr_number=6, noise=0.01, drift=0.01, random_state=42
+        duration=30,
+        sampling_rate=sampling_rate,
+        scr_number=6,
+        noise=0.01,
+        drift=0.01,
+        random_state=42,
     )
 
     if platform.system() == "Linux":
@@ -71,8 +88,17 @@ def test_eda_phasic():
 def test_eda_peaks():
 
     sampling_rate = 1000
-    eda = nk.eda_simulate(duration=30, sampling_rate=sampling_rate, scr_number=6, noise=0, drift=0.01, random_state=42)
-    eda_phasic = nk.eda_phasic(nk.standardize(eda), method="highpass")["EDA_Phasic"].values
+    eda = nk.eda_simulate(
+        duration=30,
+        sampling_rate=sampling_rate,
+        scr_number=6,
+        noise=0,
+        drift=0.01,
+        random_state=42,
+    )
+    eda_phasic = nk.eda_phasic(nk.standardize(eda), method="highpass")[
+        "EDA_Phasic"
+    ].values
 
     signals, info = nk.eda_peaks(eda_phasic, method="gamboa2008")
     onsets, peaks, amplitudes = biosppy.eda.basic_scr(eda_phasic, sampling_rate=1000)
@@ -85,7 +111,9 @@ def test_eda_peaks():
 
 def test_eda_process():
 
-    eda = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0, sampling_rate=250)
+    eda = nk.eda_simulate(
+        duration=30, scr_number=5, drift=0.1, noise=0, sampling_rate=250
+    )
     signals, info = nk.eda_process(eda, sampling_rate=250)
 
     assert signals.shape == (7500, 11)
@@ -118,7 +146,14 @@ def test_eda_process():
 def test_eda_plot():
 
     sampling_rate = 1000
-    eda = nk.eda_simulate(duration=30, sampling_rate=sampling_rate, scr_number=6, noise=0, drift=0.01, random_state=42)
+    eda = nk.eda_simulate(
+        duration=30,
+        sampling_rate=sampling_rate,
+        scr_number=6,
+        noise=0,
+        drift=0.01,
+        random_state=42,
+    )
     eda_summary, _ = nk.eda_process(eda, sampling_rate=sampling_rate)
 
     # Plot data over samples.
@@ -126,11 +161,17 @@ def test_eda_plot():
     # This will identify the latest figure.
     fig = plt.gcf()
     assert len(fig.axes) == 3
-    titles = ["Raw and Cleaned Signal", "Skin Conductance Response (SCR)", "Skin Conductance Level (SCL)"]
+    titles = [
+        "Raw and Cleaned Signal",
+        "Skin Conductance Response (SCR)",
+        "Skin Conductance Level (SCL)",
+    ]
     for (ax, title) in zip(fig.get_axes(), titles):
         assert ax.get_title() == title
     assert fig.get_axes()[2].get_xlabel() == "Samples"
-    np.testing.assert_array_equal(fig.axes[0].get_xticks(), fig.axes[1].get_xticks(), fig.axes[2].get_xticks())
+    np.testing.assert_array_equal(
+        fig.axes[0].get_xticks(), fig.axes[1].get_xticks(), fig.axes[2].get_xticks()
+    )
     plt.close(fig)
 
     # Plot data over seconds.
@@ -145,7 +186,11 @@ def test_eda_eventrelated():
     eda = nk.eda_simulate(duration=15, scr_number=3)
     eda_signals, info = nk.eda_process(eda, sampling_rate=1000)
     epochs = nk.epochs_create(
-        eda_signals, events=[5000, 10000, 15000], sampling_rate=1000, epochs_start=-0.1, epochs_end=1.9
+        eda_signals,
+        events=[5000, 10000, 15000],
+        sampling_rate=1000,
+        epochs_start=-0.1,
+        epochs_end=1.9,
     )
     eda_eventrelated = nk.eda_eventrelated(epochs)
 
@@ -155,25 +200,33 @@ def test_eda_eventrelated():
     assert len(eda_eventrelated["Label"]) == 3
 
     # Test warning on missing columns
-    with pytest.warns(nk.misc.NeuroKitWarning, match=r".*does not have an `EDA_Phasic`.*"):
+    with pytest.warns(
+        nk.misc.NeuroKitWarning, match=r".*does not have an `EDA_Phasic`.*"
+    ):
         first_epoch_key = list(epochs.keys())[0]
         first_epoch_copy = epochs[first_epoch_key].copy()
         del first_epoch_copy["EDA_Phasic"]
         nk.eda_eventrelated({**epochs, first_epoch_key: first_epoch_copy})
 
-    with pytest.warns(nk.misc.NeuroKitWarning, match=r".*does not have an `SCR_Amplitude`.*"):
+    with pytest.warns(
+        nk.misc.NeuroKitWarning, match=r".*does not have an `SCR_Amplitude`.*"
+    ):
         first_epoch_key = list(epochs.keys())[0]
         first_epoch_copy = epochs[first_epoch_key].copy()
         del first_epoch_copy["SCR_Amplitude"]
         nk.eda_eventrelated({**epochs, first_epoch_key: first_epoch_copy})
 
-    with pytest.warns(nk.misc.NeuroKitWarning, match=r".*does not have an `SCR_RecoveryTime`.*"):
+    with pytest.warns(
+        nk.misc.NeuroKitWarning, match=r".*does not have an `SCR_RecoveryTime`.*"
+    ):
         first_epoch_key = list(epochs.keys())[0]
         first_epoch_copy = epochs[first_epoch_key].copy()
         del first_epoch_copy["SCR_RecoveryTime"]
         nk.eda_eventrelated({**epochs, first_epoch_key: first_epoch_copy})
 
-    with pytest.warns(nk.misc.NeuroKitWarning, match=r".*does not have an `SCR_RiseTime`.*"):
+    with pytest.warns(
+        nk.misc.NeuroKitWarning, match=r".*does not have an `SCR_RiseTime`.*"
+    ):
         first_epoch_key = list(epochs.keys())[0]
         first_epoch_copy = epochs[first_epoch_key].copy()
         del first_epoch_copy["SCR_RiseTime"]
@@ -189,12 +242,16 @@ def test_eda_intervalrelated():
     # Test with signal dataframe
     features_df = nk.eda_intervalrelated(df)
 
-    assert all(elem in columns for elem in np.array(features_df.columns.values, dtype=str))
+    assert all(
+        elem in columns for elem in np.array(features_df.columns.values, dtype=str)
+    )
     assert features_df.shape[0] == 1  # Number of rows
 
     # Test with dict
     epochs = nk.epochs_create(df, events=[0, 25300], sampling_rate=100, epochs_end=20)
     features_dict = nk.eda_intervalrelated(epochs)
 
-    assert all(elem in columns for elem in np.array(features_dict.columns.values, dtype=str))
+    assert all(
+        elem in columns for elem in np.array(features_dict.columns.values, dtype=str)
+    )
     assert features_dict.shape[0] == 2  # Number of rows
